export declare type Dictionary<T> = Record<string, T>;
export declare enum TokenType {
    UNKNOWN = 0,
    ID = 1,
    NUM = 2,
    STR = 3,
    BOOL = 4,
    NULL = 5,
    PUNCT = 6,
    ASSIGNMENT = 7,
    FUNCTIION = 8,
    FUNCTION_CALL = 9,
    EOT = 10
}
export declare enum SyntaxType {
    EMPTY = 0,
    PATH = 1,
    SELECTOR = 2,
    OBJ_PRED = 3,
    LOGICAL_EXPR = 4,
    COMPARISON_EXPR = 5,
    MATH_EXPR = 6,
    CONCAT_EXPR = 7,
    UNARY_EXPR = 8,
    POS_EXPR = 9,
    ASSIGNMENT_EXPR = 10,
    LITERAL = 11,
    OBJECT_EXPR = 12,
    ARRAY_EXPR = 13,
    FUNCTION_EXPR = 14,
    FUNCTION_CALL_EXPR = 15,
    STATEMENTS_EXPR = 16
}
export declare type Token = {
    type: TokenType;
    value?: any;
    range: [number, number];
};
export interface Expression {
    type: SyntaxType;
    [key: string]: any;
}
export interface FunctionExpression extends Expression {
    params: string[];
    body: StatementsExpression;
}
export interface ObjectExpression extends Expression {
    props: Dictionary<Expression>;
}
export interface ArrayExpression extends Expression {
    elements: Expression[];
}
export interface StatementsExpression extends Expression {
    statements: Expression[];
}
export interface ObjectPredicateExpression extends Expression {
    arg: Expression;
}
export interface UnaryExpression extends Expression {
    arg: Expression;
    op: string;
}
export interface BinaryExpression extends Expression {
    args: [Expression, Expression];
    op: string;
}
export interface ConcatExpression extends Expression {
    args: Expression[];
}
export interface AssignmentExpression extends Expression {
    id: string;
    value: Expression;
}
export interface PosExpression extends Expression {
    fromIdx?: Expression;
    toIdx?: Expression;
    idx?: Expression;
}
export interface LiteralExpression extends Expression {
    value: string | number | boolean | null;
}
export interface PathExpression extends Expression {
    parts: Expression[];
    root?: string;
}
export interface SelectorExpression extends Expression {
    selector: string;
    prop?: string;
}
export interface FunctionCallExpression extends Expression {
    args: Expression[];
    id: string;
}
//# sourceMappingURL=types.d.ts.map